@@ -1,3 +1,3 @@
 from .load import loadata,loadmany,getIntraday
-from .Notation import notation
+from .Notation import notation,notation_code,notation_value
 from .tech import getCours,getKeyIndicators,getDividend,getIndex,getPond,getIndexRecap
\ No newline at end of file
